@@ -34,8 +34,7 @@ class ToscaNetwork(HotResource):
         pass
 
     def handle_properties(self):
-        tosca_props = self._get_tosca_props(
-            self.nodetemplate.get_properties_objects())
+        tosca_props = self.get_tosca_props()
 
         net_props = {}
         for key, value in tosca_props.items():
@@ -73,8 +72,7 @@ class ToscaNetwork(HotResource):
         if self.hide_resource:
             return
 
-        tosca_props = self._get_tosca_props(
-            self.nodetemplate.get_properties_objects())
+        tosca_props = self.get_tosca_props()
 
         subnet_props = {}
 
