@@ -19,7 +19,9 @@ import six
 from toscaparser.functions import GetAttribute
 from toscaparser.functions import GetInput
 from toscaparser.functions import GetProperty
+from toscaparser.properties import Property
 from toscaparser.relationship_template import RelationshipTemplate
+from toscaparser.utils.gettextutils import _
 from translator.common.exception import ToscaClassAttributeError
 from translator.common.exception import ToscaClassImportError
 from translator.common.exception import ToscaModImportError
@@ -141,7 +143,9 @@ class TranslateNodeTemplates(object):
         # list of all HOT resources generated
         self.hot_resources = []
         # mapping between TOSCA nodetemplate and HOT resource
+        log.debug(_('Mapping between TOSCA nodetemplate and HOT resource.'))
         self.hot_lookup = {}
+        self.policies = self.tosca.topology_template.policies
 
     def translate(self):
         return self._translate_nodetemplates()
@@ -155,20 +159,25 @@ class TranslateNodeTemplates(object):
         for depend_on in resource.depends_on_nodes:
             self._recursive_handle_properties(depend_on)
 
-        resource.handle_properties()
+        if resource.type == "OS::Nova::ServerGroup":
+            resource.handle_properties(self.hot_resources)
+        else:
+            resource.handle_properties()
 
     def _translate_nodetemplates(self):
 
+        log.debug(_('Translating the node templates.'))
         suffix = 0
         # Copy the TOSCA graph: nodetemplate
         for node in self.nodetemplates:
-            hot_node = TOSCA_TO_HOT_TYPE[node.type](node)
+            base_type = HotResource.get_base_type(node.type_definition)
+            hot_node = TOSCA_TO_HOT_TYPE[base_type.type](node)
             self.hot_resources.append(hot_node)
             self.hot_lookup[node] = hot_node
 
             # BlockStorage Attachment is a special case,
             # which doesn't match to Heat Resources 1 to 1.
-            if node.type == "tosca.nodes.Compute":
+            if base_type.type == "tosca.nodes.Compute":
                 volume_name = None
                 requirements = node.requirements
                 if requirements:
@@ -193,6 +202,18 @@ class TranslateNodeTemplates(object):
                                                                 volume_name)
                     if attachment_node:
                         self.hot_resources.append(attachment_node)
+                for i in self.tosca.inputs:
+                    if (i.name == 'key_name' and
+                            node.get_property_value('key_name') is None):
+                        schema = {'type': i.type, 'default': i.default}
+                        value = {"get_param": "key_name"}
+                        prop = Property(i.name, value, schema)
+                        node._properties.append(prop)
+
+        for policy in self.policies:
+            policy_type = policy.type_definition
+            policy_node = TOSCA_TO_HOT_TYPE[policy_type.type](policy)
+            self.hot_resources.append(policy_node)
 
         # Handle life cycle operations: this may expand each node
         # into multiple HOT resources and may change their name
@@ -274,22 +295,66 @@ class TranslateNodeTemplates(object):
             inputs = resource.properties.get('input_values')
             if inputs:
                 for name, value in six.iteritems(inputs):
-                    if isinstance(value, GetAttribute):
-                        # for the attribute
-                        # get the proper target type to perform the translation
-                        args = value.result()
-                        target = args[0]
-                        hot_target = self.find_hot_resource(target)
-
-                        inputs[name] = hot_target.get_hot_attribute(args[1],
-                                                                    args)
-                    else:
-                        if isinstance(value, GetProperty) or \
-                                isinstance(value, GetInput):
-                            inputs[name] = value.result()
+                    inputs[name] = self._translate_input(value, resource)
 
         return self.hot_resources
 
+    def _translate_input(self, input_value, resource):
+        get_property_args = None
+        if isinstance(input_value, GetProperty):
+            get_property_args = input_value.args
+        # to remove when the parser is fixed to return GetProperty
+        if isinstance(input_value, dict) and 'get_property' in input_value:
+            get_property_args = input_value['get_property']
+        if get_property_args is not None:
+            hot_target = self._find_hot_resource_for_tosca(
+                get_property_args[0], resource)
+            if hot_target:
+                props = hot_target.get_tosca_props()
+                prop_name = get_property_args[1]
+                if prop_name in props:
+                    return props[prop_name]
+        elif isinstance(input_value, GetAttribute):
+            # for the attribute
+            # get the proper target type to perform the translation
+            args = input_value.result()
+            hot_target = self._find_hot_resource_for_tosca(args[0], resource)
+
+            return hot_target.get_hot_attribute(args[1], args)
+        # most of artifacts logic should move to the parser
+        elif isinstance(input_value, dict) and 'get_artifact' in input_value:
+            get_artifact_args = input_value['get_artifact']
+
+            hot_target = self._find_hot_resource_for_tosca(
+                get_artifact_args[0], resource)
+            artifacts = TranslateNodeTemplates.get_all_artifacts(
+                hot_target.nodetemplate)
+
+            if get_artifact_args[1] in artifacts:
+                artifact = artifacts[get_artifact_args[1]]
+                if artifact.get('type', None) == 'tosca.artifacts.File':
+                    return {'get_file': artifact.get('file')}
+        elif isinstance(input_value, GetInput):
+            if isinstance(input_value.args, list) \
+                    and len(input_value.args) == 1:
+                return {'get_param': input_value.args[0]}
+            else:
+                return {'get_param': input_value.args}
+
+        return input_value
+
+    @staticmethod
+    def get_all_artifacts(nodetemplate):
+        artifacts = nodetemplate.type_definition.get_value('artifacts',
+                                                           parent=True)
+        if not artifacts:
+            artifacts = {}
+        tpl_artifacts = nodetemplate.entity_tpl.get('artifacts')
+        if tpl_artifacts:
+            artifacts.update(tpl_artifacts)
+
+        return artifacts
+
     def _get_attachment_node(self, node, suffix, volume_name):
         attach = False
         ntpl = self.nodetemplates
@@ -350,11 +415,21 @@ class TranslateNodeTemplates(object):
             if node.name == tosca_name:
                 return node
 
-    def _find_hot_resource_for_tosca(self, tosca_name):
+    def _find_hot_resource_for_tosca(self, tosca_name,
+                                     current_hot_resource=None):
+        if tosca_name == 'SELF':
+            return current_hot_resource
+        if tosca_name == 'HOST' and current_hot_resource is not None:
+            for req in current_hot_resource.nodetemplate.requirements:
+                if 'host' in req:
+                    return self._find_hot_resource_for_tosca(req['host'])
+
         for node in self.nodetemplates:
             if node.name == tosca_name:
                 return self.hot_lookup[node]
 
+        return None
+
     def _create_connect_configs(self, source_node, target_name,
                                 connect_interfaces):
         connectsto_resources = []
@@ -381,7 +456,7 @@ class TranslateNodeTemplates(object):
                 msg = _("Template error:  "
                         "no configuration found for ConnectsTo "
                         "in {1}").format(self.nodetemplate.name)
-                log.warning(msg)
+                log.error(msg)
                 raise Exception(msg)
         config_name = source_node.name + '_' + target_name + '_connect_config'
         implement = connect_config.get('implementation')
