@@ -484,7 +484,8 @@ class ToscaHotTranslationTest(TestCase):
             ValidationError,
             TranslationUtils.compare_tosca_translation_with_hot,
             tosca_file, hot_file, params)
-        expected_msg = _('Import "Definitions/wordpress.yaml" is not valid.')
+        expected_msg = _('Import '
+                         '"Invalid_import_path/wordpress.yaml" is not valid.')
         ExceptionCollector.assertExceptionMessage(ImportError, expected_msg)
 
     def test_translate_csar_wordpress_invalid_script_url(self):
@@ -501,3 +502,132 @@ class ToscaHotTranslationTest(TestCase):
                          'heat-translator/master/translator/tests/data/'
                          'custom_types/wordpress1.yaml" cannot be accessed.')
         ExceptionCollector.assertExceptionMessage(URLException, expected_msg)
+
+    def test_hot_translate_flavor_image(self):
+        tosca_file = '../tests/data/test_tosca_flavor_and_image.yaml'
+        hot_file = '../tests/data/hot_output/hot_flavor_and_image.yaml'
+        diff = TranslationUtils.compare_tosca_translation_with_hot(tosca_file,
+                                                                   hot_file,
+                                                                   {})
+        self.assertEqual({}, diff, '<difference> : ' +
+                         json.dumps(diff, indent=4, separators=(', ', ': ')))
+
+    def test_hot_translate_flavor_image_params(self):
+        tosca_file = '../tests/data/test_tosca_flavor_and_image.yaml'
+        hot_file = '../tests/data/hot_output/hot_flavor_and_image_params.yaml'
+        params = {'key_name': 'paramkey'}
+        diff = TranslationUtils.compare_tosca_translation_with_hot(tosca_file,
+                                                                   hot_file,
+                                                                   params)
+        self.assertEqual({}, diff, '<difference> : ' +
+                         json.dumps(diff, indent=4, separators=(', ', ': ')))
+
+    def test_hot_translate_custom_type(self):
+        tosca_file = '../tests/data/test_tosca_custom_type.yaml'
+        hot_file = '../tests/data/hot_output/' \
+            'hot_custom_type.yaml'
+        params = {}
+        diff = TranslationUtils.compare_tosca_translation_with_hot(tosca_file,
+                                                                   hot_file,
+                                                                   params)
+        self.assertEqual({}, diff, '<difference> : ' +
+                         json.dumps(diff, indent=4, separators=(', ', ': ')))
+
+    def test_hot_translate_custom_type_with_override(self):
+        tosca_file = '../tests/data/test_tosca_custom_type_with_override.yaml'
+        hot_file = '../tests/data/hot_output/' \
+            'hot_custom_type_with_override.yaml'
+        params = {}
+        diff = TranslationUtils.compare_tosca_translation_with_hot(tosca_file,
+                                                                   hot_file,
+                                                                   params)
+        self.assertEqual({}, diff, '<difference> : ' +
+                         json.dumps(diff, indent=4, separators=(', ', ': ')))
+
+    def test_hot_translate_custom_type_with_param_override(self):
+        tosca_file = '../tests/data/test_tosca_custom_type_with_override.yaml'
+        hot_file = '../tests/data/hot_output/' \
+            'hot_custom_type_with_param_override.yaml'
+        params = {'install_path': '/home/custom/from/cli'}
+        diff = TranslationUtils.compare_tosca_translation_with_hot(tosca_file,
+                                                                   hot_file,
+                                                                   params)
+        self.assertEqual({}, diff, '<difference> : ' +
+                         json.dumps(diff, indent=4, separators=(', ', ': ')))
+
+    def test_hot_translate_artifact(self):
+        tosca_file = '../tests/data/test_tosca_artifact.yaml'
+        hot_file = '../tests/data/hot_output/' \
+            'hot_artifact.yaml'
+        params = {}
+        diff = TranslationUtils.compare_tosca_translation_with_hot(tosca_file,
+                                                                   hot_file,
+                                                                   params)
+        self.assertEqual({}, diff, '<difference> : ' +
+                         json.dumps(diff, indent=4, separators=(', ', ': ')))
+
+    def test_hot_translate_without_tosca_os_version(self):
+        tosca_file = '../tests/data/' \
+            'test_single_server_without_optional_version_prop.yaml'
+        hot_file = '../tests/data/hot_output/' \
+            'hot_single_server_without_tosca_os_version.yaml'
+        params = {}
+        diff = TranslationUtils.compare_tosca_translation_with_hot(tosca_file,
+                                                                   hot_file,
+                                                                   params)
+        self.assertEqual({}, diff, '<difference> : ' +
+                         json.dumps(diff, indent=4, separators=(', ', ': ')))
+
+    def test_hot_translate_helloworld_with_userkey(self):
+        tosca_file = '../tests/data/tosca_helloworld.yaml'
+        hot_file = '../tests/data/hot_output/hot_hello_world_userkey.yaml'
+        params = {'key_name': 'userkey'}
+        diff = TranslationUtils.compare_tosca_translation_with_hot(tosca_file,
+                                                                   hot_file,
+                                                                   params)
+        self.assertEqual({}, diff, '<difference> : ' +
+                         json.dumps(diff, indent=4, separators=(', ', ': ')))
+
+    def test_hot_translate_custom_networks_nodes_inline(self):
+        tosca_file = '../tests/data/network/' \
+                     'test_tosca_custom_network_nodes_inline.yaml'
+        hot_file = '../tests/data/hot_output/network/' \
+                   'hot_custom_network_nodes.yaml'
+        params = {}
+        diff = TranslationUtils.compare_tosca_translation_with_hot(tosca_file,
+                                                                   hot_file,
+                                                                   params)
+        self.assertEqual({}, diff, '<difference> : ' +
+                         json.dumps(diff, indent=4, separators=(', ', ': ')))
+
+    def test_hot_translate_custom_networks_nodes_imports(self):
+        tosca_file = '../tests/data/network/' \
+                     'test_tosca_custom_network_nodes_imports.yaml'
+        hot_file = '../tests/data/hot_output/network/' \
+                   'hot_custom_network_nodes.yaml'
+        params = {}
+        diff = TranslationUtils.compare_tosca_translation_with_hot(tosca_file,
+                                                                   hot_file,
+                                                                   params)
+        self.assertEqual({}, diff, '<difference> : ' +
+                         json.dumps(diff, indent=4, separators=(', ', ': ')))
+
+    def test_hot_translate_nfv_sample(self):
+        tosca_file = '../tests/data/test_tosca_nfv_sample.yaml'
+        hot_file = '../tests/data/hot_output/hot_nfv_sample.yaml'
+        params = {}
+        diff = TranslationUtils.compare_tosca_translation_with_hot(tosca_file,
+                                                                   hot_file,
+                                                                   params)
+        self.assertEqual({}, diff, '<difference> : ' +
+                         json.dumps(diff, indent=4, separators=(', ', ': ')))
+
+    def test_hot_translate_policy(self):
+        tosca_file = '../tests/data/tosca_policies.yaml'
+        hot_file = '../tests/data/hot_output/hot_policies.yaml'
+        params = {}
+        diff = TranslationUtils.compare_tosca_translation_with_hot(tosca_file,
+                                                                   hot_file,
+                                                                   params)
+        self.assertEqual({}, diff, '<difference> : ' +
+                         json.dumps(diff, indent=4, separators=(', ', ': ')))
